@@ -15,7 +15,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.11.2.6 2003/05/15 17:00:24 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.16 2002/03/25 18:09:25 shadow Exp $");
 
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
@@ -31,7 +31,6 @@ RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.11.2.6 2003/05/15 17
 
 struct vcache *afs_globalVp = 0;
 struct vfs *afs_globalVFS = 0;
-struct nameidata afs_cacheNd;
 int afs_was_mounted = 0; /* Used to force reload if mount/unmount/mount */
 
 extern struct super_operations afs_sops;
@@ -270,7 +269,6 @@ void afs_put_super(struct super_block *sbp)
     afs_globalVFS = 0;
     afs_globalVp = 0;
     afs_shutdown();
-    path_release(&afs_cacheNd);
 
     osi_linux_verify_alloced_memory();
  done:
@@ -338,7 +336,9 @@ int afs_statfs(struct super_block *sbp, struct statfs *statp, int size)
 void 
 afs_umount_begin(struct super_block *sbp)
 {
+    afs_put_super(sbp);      
     afs_shuttingdown=1;
+    afs_was_mounted=0;
 }
 
 #if defined(AFS_LINUX24_ENV)
@@ -348,7 +348,7 @@ struct super_operations afs_sops = {
     delete_inode:      afs_delete_inode,
     put_super:         afs_put_super,
     statfs:            afs_statfs,
-    umount_begin:      afs_umount_begin
+    umount_begin:      NULL /* afs_umount_begin */
 };
 #else
 struct super_operations afs_sops = {
@@ -362,7 +362,7 @@ struct super_operations afs_sops = {
     afs_statfs,
     NULL,		/* afs_remount_fs - see doc above */
     NULL,		/* afs_clear_inode */
-    afs_umount_begin
+    NULL                /* afs_umount_begin */
 };
 #endif
 
@@ -463,13 +463,3 @@ void vcache2inode(struct vcache *avc)
     VATTR_NULL(&vattr);
     afs_CopyOutAttrs(avc, &vattr); /* calls vattr2inode */
 }
-
-/* Yet another one for fakestat'ed mountpoints */
-void vcache2fakeinode(struct vcache *rootvp, struct vcache *mpvp)
-{
-    struct vattr vattr;
-
-    VATTR_NULL(&vattr);
-    afs_CopyOutAttrs(rootvp, &vattr);
-    vattr2inode(AFSTOV(mpvp), &vattr);
-}
