@@ -20,7 +20,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_dirops.c,v 1.4.4.3 2002/04/24 01:41:40 zacheiss Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_dirops.c,v 1.10 2002/04/02 05:09:56 kolya Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -55,13 +55,14 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
     register struct conn *tc;
     struct VenusFid newFid;
     register struct dcache *tdc;
-    afs_int32 offset, len;
+    afs_size_t offset, len;
     register struct vcache *tvc;
     struct AFSStoreStatus InStatus;
     struct AFSFetchStatus OutFidStatus, OutDirStatus;
     struct AFSCallBack CallBack;
     struct AFSVolSync tsync;
     afs_int32 now;
+    struct afs_fakestat_state fakestate;
     XSTATS_DECLS
     OSI_VC_CONVERT(adp)
 
@@ -71,6 +72,7 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
 
     if (code = afs_InitReq(&treq, acred)) 
 	goto done2;
+    afs_InitFakeStat(&fakestate);
 
     if (strlen(aname) > AFSNAMEMAX) {
 	code = ENAMETOOLONG;
@@ -81,6 +83,8 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
 	code = EINVAL;
 	goto done;
     }
+    code = afs_EvalFakeStat(&adp, &fakestate, &treq);
+    if (code) goto done;
     code = afs_VerifyVCache(adp, &treq);
     if (code) goto done;
 
@@ -96,7 +100,7 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
     InStatus.ClientModTime = osi_Time();
     InStatus.UnixModeBits = attrs->va_mode & 0xffff;   /* only care about protection bits */
     InStatus.Group = (afs_int32)acred->cr_gid;
-    tdc = afs_GetDCache(adp, 0, &treq, &offset, &len, 1);
+    tdc = afs_GetDCache(adp, (afs_size_t) 0, &treq, &offset, &len, 1);
     ObtainWriteLock(&adp->lock,153);
     do {
 	tc = afs_Conn(&adp->fid, &treq, SHARED_LOCK);
@@ -134,6 +138,7 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
 	goto done;
     }
     /* otherwise, we should see if we can make the change to the dir locally */
+    if (tdc) ObtainWriteLock(&tdc->lock, 632);
     if (afs_LocalHero(adp, tdc, &OutDirStatus, 1)) {
         /* we can do it locally */
         code = afs_dir_Create(&tdc->f.inode, aname, &newFid.Fid);
@@ -143,6 +148,7 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
 	}
     }
     if (tdc) {
+	ReleaseWriteLock(&tdc->lock);
 	afs_PutDCache(tdc);
     }
     adp->m.LinkCount = OutDirStatus.LinkCount;
@@ -157,6 +163,7 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
     }
     else code = ENOENT;
 done:
+    afs_PutFakeStat(&fakestate);
     code = afs_CheckCode(code, &treq, 26);
 done2:
 #ifdef	AFS_OSF_ENV
@@ -189,9 +196,10 @@ afs_rmdir(adp, aname, acred)
     register struct vcache *tvc = (struct vcache *)0;
     register afs_int32 code;
     register struct conn *tc;
-    afs_int32 offset, len;
+    afs_size_t offset, len;
     struct AFSFetchStatus OutDirStatus;
     struct AFSVolSync tsync;
+    struct afs_fakestat_state fakestate;
     XSTATS_DECLS
     OSI_VC_CONVERT(adp)
 
@@ -200,14 +208,19 @@ afs_rmdir(adp, aname, acred)
     afs_Trace2(afs_iclSetp, CM_TRACE_RMDIR, ICL_TYPE_POINTER, adp, 
 	       ICL_TYPE_STRING, aname);
 
-    if (code = afs_InitReq(&treq, acred)) 
+    if (code = afs_InitReq(&treq, acred))
 	goto done2;
+    afs_InitFakeStat(&fakestate);
 
     if (strlen(aname) > AFSNAMEMAX) {
 	code = ENAMETOOLONG;
 	goto done;
     }
 
+    code = afs_EvalFakeStat(&adp, &fakestate, &treq);
+    if (code)
+	goto done;
+
     code = afs_VerifyVCache(adp, &treq);
     if (code) goto done;
 
@@ -219,8 +232,9 @@ afs_rmdir(adp, aname, acred)
         goto done;
     }
 
-    tdc	= afs_GetDCache(adp, 0,	&treq, &offset,	&len, 1);	/* test for error below */
+    tdc	= afs_GetDCache(adp, (afs_size_t) 0,	&treq, &offset,	&len, 1);	/* test for error below */
     ObtainWriteLock(&adp->lock,154);
+    if (tdc) ObtainSharedLock(&tdc->lock, 633);
     if (tdc && (adp->states & CForeign)) {
 	struct VenusFid unlinkFid;
 
@@ -263,7 +277,10 @@ afs_rmdir(adp, aname, acred)
 		   AFS_STATS_FS_RPCIDX_REMOVEDIR, SHARED_LOCK, (struct cell *)0));
 
     if (code) {
-	if (tdc) afs_PutDCache(tdc);
+	if (tdc) {
+	    ReleaseSharedLock(&tdc->lock);
+	    afs_PutDCache(tdc);
+	}
 	if (code < 0) {
 	  ObtainWriteLock(&afs_xcbhash, 491);
 	  afs_DequeueCallback(adp);
@@ -276,6 +293,7 @@ afs_rmdir(adp, aname, acred)
     }
     /* here if rpc worked; update the in-core link count */
     adp->m.LinkCount = OutDirStatus.LinkCount;
+    if (tdc) UpgradeSToWLock(&tdc->lock, 634);
     if (afs_LocalHero(adp, tdc, &OutDirStatus, 1)) {
 	/* we can do it locally */
 	code = afs_dir_Delete(&tdc->f.inode, aname);
@@ -285,6 +303,7 @@ afs_rmdir(adp, aname, acred)
 	}
     }
     if (tdc) {
+	ReleaseWriteLock(&tdc->lock);
 	afs_PutDCache(tdc);	/* drop ref count */
     }
 
@@ -306,6 +325,7 @@ afs_rmdir(adp, aname, acred)
     code = 0;
 
 done:
+    afs_PutFakeStat(&fakestate);
     code = afs_CheckCode(code, &treq, 27); 
 done2:
 #ifdef	AFS_OSF_ENV
