@@ -22,7 +22,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_remove.c,v 1.10 2002/02/08 17:28:44 kolya Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_remove.c,v 1.17 2002/04/22 16:05:10 shadow Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -213,7 +213,7 @@ char *Tnam1;
 #ifdef	AFS_OSF_ENV
 afs_remove(ndp)
     struct nameidata *ndp; {
-    register struct vcache *adp = (struct vcache *)ndp->ni_dvp;
+    register struct vcache *adp = VTOAFS(ndp->ni_dvp);
     char *aname = ndp->ni_dent.d_name;
     struct ucred *acred = ndp->ni_cred;
 #else	/* AFS_OSF_ENV */
@@ -230,6 +230,7 @@ afs_remove(OSI_VC_ARG(adp), aname, acred)
     afs_size_t offset, len;
     struct AFSFetchStatus OutDirStatus;
     struct AFSVolSync tsync;
+    struct afs_fakestat_state fakestate;
     XSTATS_DECLS
     OSI_VC_CONVERT(adp)
 
@@ -237,26 +238,63 @@ afs_remove(OSI_VC_ARG(adp), aname, acred)
     afs_Trace2(afs_iclSetp, CM_TRACE_REMOVE, ICL_TYPE_POINTER, adp,
 	       ICL_TYPE_STRING, aname);
 
-    /* Check if this is dynroot */
-    if (afs_IsDynroot(adp))
-	return afs_DynrootVOPRemove(adp, acred, aname);
+#ifdef	AFS_OSF_ENV
+    tvc = (struct vcache *)ndp->ni_vp;  /* should never be null */
+#endif
 
-    if (code = afs_InitReq(&treq, acred))
-      return code;
+    if (code = afs_InitReq(&treq, acred)) {
+#ifdef  AFS_OSF_ENV
+	afs_PutVCache(adp, 0);
+	afs_PutVCache(tvc, 0);
+#endif
+	return code;
+    }
+
+    afs_InitFakeStat(&fakestate);
+    code = afs_EvalFakeStat(&adp, &fakestate, &treq);
+    if (code) {
+	afs_PutFakeStat(&fakestate);
+#ifdef  AFS_OSF_ENV
+	afs_PutVCache(adp, 0);
+	afs_PutVCache(tvc, 0);
+#endif
+	return code;
+    }
+
+    /* Check if this is dynroot */
+    if (afs_IsDynroot(adp)) {
+	code = afs_DynrootVOPRemove(adp, acred, aname);
+	afs_PutFakeStat(&fakestate);
+#ifdef  AFS_OSF_ENV
+	afs_PutVCache(adp, 0);
+	afs_PutVCache(tvc, 0);
+#endif
+	return code;
+    }
+    if (strlen(aname) > AFSNAMEMAX) {
+	afs_PutFakeStat(&fakestate);
+#ifdef  AFS_OSF_ENV
+	afs_PutVCache(adp, 0);
+	afs_PutVCache(tvc, 0);
+#endif
+	return ENAMETOOLONG;
+    }
 tagain:
     code = afs_VerifyVCache(adp, &treq);
 #ifdef	AFS_OSF_ENV
-    tvc = (struct vcache *)ndp->ni_vp;  /* should never be null */
+    tvc = VTOAFS(ndp->ni_vp);  /* should never be null */
     if (code) {
 	afs_PutVCache(adp, 0);
 	afs_PutVCache(tvc, 0);
+	afs_PutFakeStat(&fakestate);
 	return afs_CheckCode(code, &treq, 22);
     }
 #else	/* AFS_OSF_ENV */
     tvc = (struct vcache *) 0;
     if (code) {
-      code = afs_CheckCode(code, &treq, 23);
-      return code;
+	code = afs_CheckCode(code, &treq, 23);
+	afs_PutFakeStat(&fakestate);
+	return code;
     }
 #endif
 
@@ -264,7 +302,12 @@ tagain:
       * fileserver
       */
     if ( adp->states & CRO ) {
+#ifdef  AFS_OSF_ENV
+        afs_PutVCache(adp, 0);
+        afs_PutVCache(tvc, 0);
+#endif
         code = EROFS;
+	afs_PutFakeStat(&fakestate);
 	return code;
     }
 
@@ -339,7 +382,7 @@ tagain:
 
 	ReleaseWriteLock(&adp->lock);
 	if (tdc) ReleaseSharedLock(&tdc->lock);
-	code = afsrename(adp, aname, adp, unlname, acred);
+	code = afsrename(adp, aname, adp, unlname, acred, &treq);
 	Tnam1 = unlname;
 	if (!code) {
 	    tvc->mvid = (struct VenusFid *)unlname;
@@ -361,6 +404,7 @@ tagain:
 #ifdef	AFS_OSF_ENV
     afs_PutVCache(adp, WRITE_LOCK);
 #endif	/* AFS_OSF_ENV */
+    afs_PutFakeStat(&fakestate);
     return code;
 }
 
@@ -398,6 +442,17 @@ afs_remunlink(avc, doit)
 	    cred = avc->uncred;
 	    avc->uncred = NULL;
 
+#ifdef AFS_DARWIN_ENV
+           /* this is called by vrele (via VOP_INACTIVE) when the refcount
+              is 0. we can't just call VN_HOLD since vref will panic.
+              we can't just call osi_vnhold because a later AFS_RELE will call
+              vrele again, which will try to call VOP_INACTIVE again after
+              vn_locking the vnode. which would be fine except that our vrele
+              caller also locked the vnode... So instead, we just gimmick the
+              refcounts and hope nobody else can touch the file now */
+	    osi_Assert(VREFCOUNT(avc) == 0);
+	    VREFCOUNT_SET(avc, 1);
+#endif
 	    VN_HOLD(&avc->v);
 
 	    /* We'll only try this once. If it fails, just release the vnode.
@@ -428,6 +483,10 @@ afs_remunlink(avc, doit)
 	    }
 	    osi_FreeSmallSpace(unlname);
 	    crfree(cred);
+#ifdef AFS_DARWIN_ENV
+	    osi_Assert(VREFCOUNT(avc) == 1);
+	    VREFCOUNT_SET(avc, 0);
+#endif
         }
     }
     else {
