@@ -21,7 +21,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.4 2001/07/12 19:58:22 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.12 2002/04/02 05:09:56 kolya Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -46,7 +46,7 @@ afs_symlink
     struct nameidata *ndp;
     struct vattr *attrs;
     register char *atargetName; {
-    register struct vcache *adp = (struct vcache *)ndp->ni_dvp;
+    register struct vcache *adp = VTOAFS(ndp->ni_dvp);
     char *aname = ndp->ni_dent.d_name;
     struct ucred *acred = ndp->ni_cred;
 #else	/* AFS_OSF_ENV */
@@ -63,7 +63,8 @@ afs_symlink
     struct conn *tc;
     struct VenusFid newFid;
     struct dcache *tdc;
-    afs_int32 offset, len, alen;
+    afs_size_t offset, len;
+    afs_int32 alen;
     struct server *hostp=0;
     struct vcache *tvc;
     struct AFSStoreStatus InStatus;
@@ -71,19 +72,36 @@ afs_symlink
     struct AFSCallBack CallBack;
     struct AFSVolSync tsync;
     struct volume*    volp=0;
+    struct afs_fakestat_state fakestate;
     XSTATS_DECLS
     OSI_VC_CONVERT(adp)
     
     AFS_STATCNT(afs_symlink);
     afs_Trace2(afs_iclSetp, CM_TRACE_SYMLINK, ICL_TYPE_POINTER, adp,
                 ICL_TYPE_STRING, aname);
+
     if (code = afs_InitReq(&treq, acred))
-       return code;
+	goto done2;
+
+    afs_InitFakeStat(&fakestate);
+    code = afs_EvalFakeStat(&adp, &fakestate, &treq);
+    if (code)
+	goto done;
+
+    if (strlen(aname) > AFSNAMEMAX || strlen(atargetName) > AFSPATHMAX) {
+	code = ENAMETOOLONG;
+	goto done;
+    }
+
+    if (afs_IsDynroot(adp)) {
+	code = afs_DynrootVOPSymlink(adp, acred, aname, atargetName);
+	goto done;
+    }
 
     code = afs_VerifyVCache(adp, &treq);
     if (code) { 
-      code = afs_CheckCode(code, &treq, 30);
-      return code;
+	code = afs_CheckCode(code, &treq, 30);
+	goto done;
     }
 
     /** If the volume is read-only, return error without making an RPC to the
@@ -91,7 +109,7 @@ afs_symlink
       */
     if ( adp->states & CRO ) {
         code = EROFS;
-	return code;
+	goto done;
     }
 
     InStatus.Mask = AFS_SETMODTIME | AFS_SETMODE;
@@ -104,9 +122,10 @@ afs_symlink
 	InStatus.UnixModeBits = 0755;
 	alen++;	    /* add in the null */
     }
-    tdc = afs_GetDCache(adp, 0, &treq, &offset, &len, 1);
+    tdc = afs_GetDCache(adp, (afs_size_t) 0, &treq, &offset, &len, 1);
     volp = afs_FindVolume(&adp->fid, READ_LOCK); /*parent is also in same vol*/
     ObtainWriteLock(&adp->lock,156);
+    ObtainWriteLock(&tdc->lock, 636);
     ObtainSharedLock(&afs_xvcache,17);  /* prevent others from creating this entry */
     /* XXX Pay attention to afs_xvcache around the whole thing!! XXX */
     do {
@@ -154,7 +173,10 @@ afs_symlink
 	}
 	ReleaseWriteLock(&adp->lock);
 	ReleaseWriteLock(&afs_xvcache);
-	if (tdc) afs_PutDCache(tdc);
+	if (tdc) {
+	    ReleaseWriteLock(&tdc->lock);
+	    afs_PutDCache(tdc);
+	}
 	goto done;
     }
     /* otherwise, we should see if we can make the change to the dir locally */
@@ -167,6 +189,7 @@ afs_symlink
 	}
     }
     if (tdc) {
+	ReleaseWriteLock(&tdc->lock);
 	afs_PutDCache(tdc);
     }
     newFid.Cell = adp->fid.Cell;
@@ -206,12 +229,14 @@ afs_symlink
     afs_PutVCache(tvc, WRITE_LOCK);
     code = 0;
 done:
-#ifdef  AFS_OSF_ENV
-    AFS_RELE(ndp->ni_dvp);
-#endif  /* AFS_OSF_ENV */
+    afs_PutFakeStat(&fakestate);
     if ( volp ) 
 	afs_PutVolume(volp, READ_LOCK);
     code = afs_CheckCode(code, &treq, 31);
+done2:
+#ifdef  AFS_OSF_ENV
+    AFS_RELE(ndp->ni_dvp);
+#endif  /* AFS_OSF_ENV */
     return code;
 }
 
@@ -220,8 +245,9 @@ afs_MemHandleLink(avc, areq)
      struct vrequest *areq;
   {
       register struct dcache *tdc;
-      register char *tp;
-      afs_int32 offset, len, alen;
+      register char *tp, *rbuf;
+      afs_size_t offset, len;
+      afs_int32 tlen, alen;
       register afs_int32 code;
 
       AFS_STATCNT(afs_MemHandleLink);
@@ -230,7 +256,7 @@ afs_MemHandleLink(avc, areq)
 	 protected 755,	we add a null to the end of */
       if (!avc->linkData) {
 	  void *addr;
-	  tdc = afs_GetDCache(avc, 0, areq, &offset, &len, 0);
+	  tdc = afs_GetDCache(avc, (afs_size_t) 0, areq, &offset, &len, 0);
 	  if (!tdc) {
 	      return EIO;
 	  }
@@ -241,11 +267,19 @@ afs_MemHandleLink(avc, areq)
 	  }
 	  if (avc->m.Mode	& 0111)	alen = len+1;	/* regular link */
 	  else alen = len;			/* mt point */
-          tp = afs_osi_Alloc(alen); /* make room for terminating null */
+	  rbuf = (char *) osi_AllocLargeSpace(AFS_LRALLOCSIZ);
+	  ObtainReadLock(&tdc->lock);
           addr = afs_MemCacheOpen(tdc->f.inode);
-          code = afs_MemReadBlk(addr, 0, tp, len);
-	  tp[alen-1] = 0;
+	  tlen = len;
+          code = afs_MemReadBlk(addr, 0, rbuf, tlen);
+	  afs_MemCacheClose(addr);
+	  ReleaseReadLock(&tdc->lock);
 	  afs_PutDCache(tdc);
+	  rbuf[alen-1] = 0;
+	  alen = strlen(rbuf) + 1;
+	  tp = afs_osi_Alloc(alen); /* make room for terminating null */
+	  memcpy(tp, rbuf, alen);
+	  osi_FreeLargeSpace(rbuf);
 	  if (code != len) {
 	      afs_osi_Free(tp, alen);
 	      return EIO;
@@ -257,11 +291,13 @@ afs_MemHandleLink(avc, areq)
 
 afs_UFSHandleLink(avc, areq)
     register struct vcache *avc;
-    struct vrequest *areq; {
+    struct vrequest *areq; 
+{
     register struct dcache *tdc;
-    register char *tp;
+    register char *tp, *rbuf;
     char *tfile;
-    afs_int32 offset, len, alen;
+    afs_size_t offset, len;
+    afs_int32 tlen, alen;
     register afs_int32 code;
 
     /* two different formats, one for links protected 644, have a "." at the end
@@ -269,7 +305,10 @@ afs_UFSHandleLink(avc, areq)
 	we add a null to the end of */
    AFS_STATCNT(afs_UFSHandleLink);
     if (!avc->linkData) {
-	tdc = afs_GetDCache(avc, 0, areq, &offset, &len, 0);
+	tdc = afs_GetDCache(avc, (afs_size_t) 0, areq, &offset, &len, 0);
+	afs_Trace3(afs_iclSetp, CM_TRACE_UFSLINK, ICL_TYPE_POINTER, avc,
+			ICL_TYPE_POINTER, tdc,
+			ICL_TYPE_OFFSET, ICL_HANDLE_OFFSET(avc->m.Length));
 	if (!tdc) {
 	    return EIO;
 	}
@@ -278,15 +317,22 @@ afs_UFSHandleLink(avc, areq)
 	    afs_PutDCache(tdc);
 	    return EFAULT;
 	}
-	tfile = osi_UFSOpen (tdc->f.inode);
 	if (avc->m.Mode	& 0111)	alen = len+1;	/* regular link */
 	else alen = len;			/* mt point */
-	tp = afs_osi_Alloc(alen);			/* make room for terminating null */
-	code = afs_osi_Read(tfile, -1, tp, len);
-	tp[alen-1] = 0;
+	rbuf = (char *) osi_AllocLargeSpace(AFS_LRALLOCSIZ);
+	tlen = len;
+	ObtainReadLock(&tdc->lock);
+	tfile = osi_UFSOpen (tdc->f.inode);
+	code = afs_osi_Read(tfile, -1, rbuf, tlen);
 	osi_UFSClose(tfile);
+	ReleaseReadLock(&tdc->lock);
 	afs_PutDCache(tdc);
-	if (code != len) {
+	rbuf[alen-1] = '\0';
+	alen = strlen(rbuf) + 1;
+	tp = afs_osi_Alloc(alen);	/* make room for terminating null */
+	memcpy(tp, rbuf, alen);
+	osi_FreeLargeSpace(rbuf);
+	if (code != tlen) {
 	    afs_osi_Free(tp, alen);
 	    return EIO;
 	}
@@ -298,15 +344,20 @@ afs_UFSHandleLink(avc, areq)
 afs_readlink(OSI_VC_ARG(avc), auio, acred)
     OSI_VC_DECL(avc);
     struct uio *auio;
-    struct AFS_UCRED *acred; {
+    struct AFS_UCRED *acred; 
+{
     register afs_int32 code;
     struct vrequest treq;
     register char *tp;
+    struct afs_fakestat_state fakestat;
     OSI_VC_CONVERT(avc)
 
     AFS_STATCNT(afs_readlink);
     afs_Trace1(afs_iclSetp, CM_TRACE_READLINK, ICL_TYPE_POINTER, avc);
     if (code = afs_InitReq(&treq, acred)) return code;
+    afs_InitFakeStat(&fakestat);
+    code = afs_EvalFakeStat(&avc, &fakestat, &treq);
+    if (code) goto done;
     code = afs_VerifyVCache(avc, &treq);
     if (code) goto done;
     if (vType(avc) != VLNK) {
@@ -325,6 +376,7 @@ afs_readlink(OSI_VC_ARG(avc), auio, acred)
     }
     ReleaseWriteLock(&avc->lock);
 done:
+    afs_PutFakeStat(&fakestat);
     code = afs_CheckCode(code, &treq, 32);
     return code;
 }
