@@ -20,7 +20,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_write.c,v 1.16 2002/02/16 18:23:50 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_write.c,v 1.20 2002/04/02 17:35:03 kolya Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -59,7 +59,7 @@ register struct vrequest *treq;
 	 * top level code.  */
 	avc->opens--;
 	avc->execsOrWriters--;
-	AFS_RELE((struct vnode *)avc); /* VN_HOLD at set CCore(afs_FakeClose)*/
+	AFS_RELE(AFSTOV(avc)); /* VN_HOLD at set CCore(afs_FakeClose)*/
 	crfree((struct AFS_UCRED *)avc->linkData);	/* "crheld" in afs_FakeClose */
 	avc->linkData =	(char *)0;
     }
@@ -260,9 +260,12 @@ afs_MemWrite(avc, auio, aio, acred, noLock)
 
 	code = afs_MemWriteUIO(tdc->f.inode, &tuio);
 	if (code) {
+	    void *mep; /* XXX in prototype world is struct memCacheEntry * */
 	    error = code;
 	    ZapDCE(tdc);		/* bad data */
-	    afs_MemCacheTruncate(tdc->f.inode, 0);
+	    mep = afs_MemCacheOpen(tdc->f.inode);
+	    afs_MemCacheTruncate(mep, 0);
+	    afs_MemCacheClose(mep);
 	    afs_stats_cmperf.cacheCurrDirtyChunks--;
 	    afs_indexFlags[tdc->index] &= ~IFDataMod;    /* so it does disappear */
 	    ReleaseWriteLock(&tdc->lock);
@@ -718,23 +721,30 @@ struct vrequest *areq; {
 afs_closex(afd)
     register struct file *afd; {
     struct vrequest treq;
-    register struct vcache *tvc;
+    struct vcache *tvc;
     afs_int32 flags;
     int closeDone;
     afs_int32 code = 0;
+    struct afs_fakestat_state fakestat;
 
     AFS_STATCNT(afs_closex);
     /* setup the credentials */
     if (code = afs_InitReq(&treq, u.u_cred)) return code;
+    afs_InitFakeStat(&fakestat);
 
     closeDone = 0;
     /* we're the last one.  If we're an AFS vnode, clear the flags,
      * close the file and release the lock when done.  Otherwise, just
      * let the regular close code work.      */
     if (afd->f_type == DTYPE_VNODE) {
-	tvc = (struct vcache *) afd->f_data;
-	if (IsAfsVnode((struct vnode *)tvc)) {
-	    VN_HOLD((struct vnode *) tvc);
+	tvc = VTOAFS(afd->f_data);
+	if (IsAfsVnode(AFSTOV(tvc))) {
+	    code = afs_EvalFakeStat(&tvc, &fakestat, &treq);
+	    if (code) {
+		afs_PutFakeStat(&fakestat);
+		return code;
+	    }
+	    VN_HOLD(AFSTOV(tvc));
 	    flags = afd->f_flag & (FSHLOCK | FEXLOCK);
 	    afd->f_flag &= ~(FSHLOCK | FEXLOCK);
 	    code = vno_close(afd);
@@ -748,7 +758,7 @@ afs_closex(afd)
 #ifdef	AFS_DEC_ENV
 	    grele((struct gnode *) tvc);
 #else
-	    AFS_RELE((struct vnode *) tvc);
+	    AFS_RELE(AFSTOV(tvc));
 #endif
 	    closeDone = 1;
 	}
@@ -757,6 +767,7 @@ afs_closex(afd)
     if (!closeDone) {
 	code = vno_close(afd);
     }
+    afs_PutFakeStat(&fakestat);
     return code;	/* return code from vnode layer */
 }
 #endif
@@ -797,41 +808,44 @@ afs_close(OSI_VC_ARG(avc), aflags, acred)
     afs_int32 aflags;
     struct AFS_UCRED *acred; 
 {
-    register afs_int32 code, initreq=0;
+    register afs_int32 code;
     register struct brequest *tb;
     struct vrequest treq;
 #ifdef AFS_SGI65_ENV
     struct flid flid;
 #endif
+    struct afs_fakestat_state fakestat;
     OSI_VC_CONVERT(avc)
 
     AFS_STATCNT(afs_close);
     afs_Trace2(afs_iclSetp, CM_TRACE_CLOSE, ICL_TYPE_POINTER, avc,
 	       ICL_TYPE_INT32, aflags);
+    code = afs_InitReq(&treq, acred);
+    if (code) return code;
+    afs_InitFakeStat(&fakestat);
+    code = afs_EvalFakeStat(&avc, &fakestat, &treq);
+    if (code) {
+	afs_PutFakeStat(&fakestat);
+	return code;
+    }
 #ifdef	AFS_SUN5_ENV
     if (avc->flockCount) {
-	if (code = afs_InitReq(&treq, acred)) return code;
-	initreq = 1;
 	HandleFlock(avc, LOCK_UN, &treq, 0, 1/*onlymine*/);
     }
 #endif
 #if defined(AFS_SGI_ENV)
-    if (!lastclose)
+    if (!lastclose) {
+	afs_PutFakeStat(&fakestat);
  	return 0;
+    }
 #else
 #if	defined(AFS_SUN_ENV) || defined(AFS_SGI_ENV)
     if (count > 1) {
 	/* The vfs layer may call this repeatedly with higher "count"; only on the last close (i.e. count = 1) we should actually proceed with the close. */
+	afs_PutFakeStat(&fakestat);
 	return 0;
     }
 #endif
-#ifdef	AFS_SUN5_ENV
-    if (!initreq) {
-#endif
-#endif
-	if (code = afs_InitReq(&treq, acred)) return code;
-#ifdef	AFS_SUN5_ENV
-    }
 #endif
 #ifndef	AFS_SUN5_ENV
 #if defined(AFS_SGI_ENV)
@@ -954,6 +968,7 @@ afs_close(OSI_VC_ARG(avc), aflags, acred)
 	afs_remunlink(avc, 1);	/* ignore any return code */
     }
 #endif
+    afs_PutFakeStat(&fakestat);
     code = afs_CheckCode(code, &treq, 5);
     return code;
 }
