@@ -15,7 +15,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.5.4.4 2003/03/06 15:39:43 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.6 2001/10/08 22:15:24 shadow Exp $");
 
 #include "../afs/stds.h"
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
@@ -27,7 +27,7 @@ RCSID("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.5.4.4 2003/03/06 15:39:43 sh
 #ifdef AFS_SGI62_ENV
 #include "../h/hashing.h"
 #endif
-#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN60_ENV)
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX20_ENV)
 #include <netinet/in_var.h>
 #endif /* ! AFS_HPUX110_ENV */
 #endif /* !defined(UKERNEL) */
@@ -71,45 +71,6 @@ char *afs_cv2string(char *ttp, afs_uint32 aval)
 
 } /*afs_cv2string*/
 
-char *afs_strchr(char *s, int c)
-{
-    char *p;
-   
-    for (p = s; *p; p++)
-      if (*p == c)
-	return p;
-    return NULL;
-}
-
-int afs_strcasecmp(char *s1, char *s2)
-{
-    while (*s1 && *s2) {
-	char c1, c2;
-
-	c1 = *s1++;
-	c2 = *s2++;
-	if (c1 >= 'A' && c1 <= 'Z') c1 += 0x20;
-	if (c2 >= 'A' && c2 <= 'Z') c2 += 0x20;
-	if (c1 != c2)
-	    return c1-c2;
-    }
-
-    return *s1 - *s2;
-}
-
-char *afs_strdup(char *s)
-{
-    char *n;
-    int cc;
-
-    cc = strlen(s) + 1;
-    n = (char *) afs_osi_Alloc(cc);
-    if (n)
-	memcpy(n, s, cc);
-
-    return n;
-}
-
 void print_internet_address(char *preamble, struct srvAddr *sa,
 			    char *postamble, int flag)
 {
