@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.14 2002/01/19 16:31:25 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.16 2002/02/28 06:10:47 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -488,7 +488,7 @@ static BozoDaemon() {
 
 	/* see if we should do a restart */
 	if (now > nextRestart) {
-	    BOZO_ReBozo(0);	/* doesn't come back */
+	    SBOZO_ReBozo(0);	/* doesn't come back */
 	}
 	
 	/* see if we should restart a server */
@@ -910,9 +910,8 @@ char **envp;
     bozo_rxsc[2] = (struct rx_securityClass *) rxkad_NewServerSecurityObject(
 					 0, tdir, afsconf_GetKey, (char *) 0);
 
-    /* These two lines disallow jumbograms */
-    rx_maxReceiveSize = OLD_MAX_PACKET_SIZE;
-    rxi_nSendFrags = rxi_nRecvFrags = 1;
+    /* Disable jumbograms */
+    rx_SetNoJumbo();
 
     tservice = rx_NewService(/* port */ 0, /* service id */ 1, 
 		  /*service name */ "bozo", /* security classes */ bozo_rxsc,
