@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.9.2.4 2003/03/18 03:56:57 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.12 2002/02/28 06:10:50 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -56,8 +56,6 @@ struct kadstats dynamic_statistics;
 struct ubik_dbase *KA_dbase;
 afs_int32 myHost = 0;
 afs_int32 verbose_track = 1;
-afs_int32 krb4_cross = 0;
-
 struct afsconf_dir *KA_conf;		/* for getting cell info */
 
 extern afs_int32 ubik_lastYesTime;
@@ -196,7 +194,6 @@ main (argc, argv)
       usage:
         printf("Usage: kaserver [-noAuth] [-fastKeys] [-database <dbpath>] "
 	       "[-localfiles <lclpath>] [-minhours <n>] [-servers <serverlist>] "
-	       "[-crossrealm]"
 	       /*" [-enable_peer_stats] [-enable_process_stats] " */
 	       "[-help]\n");
 	exit(1);
@@ -254,7 +251,6 @@ main (argc, argv)
 	else if (IsArg("-clear")) level = rxkad_clear;
 	else if (IsArg("-sorry")) level = rxkad_clear;
 	else if (IsArg("-debug")) verbose_track = 0;
-	else if (IsArg("-crossrealm")) krb4_cross = 1;
 	else if (IsArg("-minhours")) {
              MinHours = atoi(argv[++a]);
         }
