@@ -7,6 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/libadmin/bos/afs_bosAdmin.c,v 1.8 2002/02/22 09:00:40 kolya Exp $");
+
 #include <stdio.h>
 #include <afs/stds.h>
 #include "afs_bosAdmin.h"
@@ -20,10 +25,12 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <stdlib.h>
 #ifdef AFS_NT40_ENV
 #include <io.h>
+#else
+#include <unistd.h>
 #endif
-#include "../../permit_xprt.h"
 
 
 /*
@@ -57,8 +64,8 @@ extern int BOZO_RestartAll();
 extern int BOZO_SetCellName();
 extern int BOZO_SetNoAuthFlag();
 extern int BOZO_SetRestartTime();
-extern int BOZO_SetStatus(struct rx_connection *, const char *, long);
-extern int BOZO_SetTStatus(struct rx_connection *, const char *, long);
+extern int BOZO_SetStatus(struct rx_connection *, char *, afs_int32);
+extern int BOZO_SetTStatus(struct rx_connection *, char *, afs_int32);
 extern int BOZO_ShutdownAll();
 extern int BOZO_StartupAll();
 extern int BOZO_UnInstall();
@@ -2088,7 +2095,6 @@ static int GetKeyRPC(
     int rc = 0;
     afs_status_t tst = 0;
     key_get_p key = (key_get_p) rpc_specific;
-    char *ptr = (char *) &key->key[slot];
     struct bozo_keyInfo keyInfo;
 
     tst = BOZO_ListKeys(key->server, key->next++,
@@ -3077,25 +3083,25 @@ int ADMINAPI bos_ExecutableRestartTimeSet(
     }
 
     if ((time.mask & BOS_RESTART_TIME_HOUR) &&
-        (time.hour < 0) || (time.hour > 23)) {
+        ((time.hour < 0) || (time.hour > 23))) {
 	tst = ADMBOSHOURINVALID;
 	goto fail_bos_ExecutableRestartTimeSet;
     }
 
     if ((time.mask & BOS_RESTART_TIME_MINUTE) &&
-	(time.min < 0) || (time.min > 60)) {
+	((time.min < 0) || (time.min > 60))) {
 	tst = ADMBOSMINUTEINVALID;
 	goto fail_bos_ExecutableRestartTimeSet;
     }
 
     if ((time.mask & BOS_RESTART_TIME_SECOND) &&
-	(time.sec < 0) || (time.sec > 60)) {
+	((time.sec < 0) || (time.sec > 60))) {
 	tst = ADMBOSSECONDINVALID;
 	goto fail_bos_ExecutableRestartTimeSet;
     }
 
     if ((time.mask & BOS_RESTART_TIME_DAY) &&
-	(time.day < 0) || (time.day > 6)) {
+	((time.day < 0) || (time.day > 6))) {
 	tst = ADMBOSDAYINVALID;
 	goto fail_bos_ExecutableRestartTimeSet;
     }
@@ -3106,7 +3112,7 @@ int ADMINAPI bos_ExecutableRestartTimeSet(
     restartTime.sec = time.sec;
     restartTime.day = time.day;
 
-    tst = BOZO_SetRestartTime(b_handle->server, restartType, restartTime);
+    tst = BOZO_SetRestartTime(b_handle->server, restartType, &restartTime);
 
     if (tst == 0) {
 	rc = 1;
@@ -3224,7 +3230,7 @@ int ADMINAPI bos_LogGet(
     int rc = 0;
     afs_status_t tst = 0;
     bos_server_p b_handle = (bos_server_p) serverHandle;
-    struct rx_call *tcall;
+    struct rx_call *tcall = NULL;
     afs_int32 error;
     char buffer;
     int have_call = 0;
@@ -3485,7 +3491,6 @@ int ADMINAPI bos_Salvage(
     int have_volume = 0;
     unsigned int part = 0;
     int try_to_stop_fileserver = 0;
-    int stopped_fileserver = 0;
     bos_ProcessType_t procType;
     bos_ProcessInfo_t procInfo;
     FILE *log = NULL;
@@ -3629,8 +3634,8 @@ int ADMINAPI bos_Salvage(
 	goto fail_bos_Salvage;
     }
 
-    while (poll_rc = bos_ProcessInfoGet(serverHandle, "salvage-tmp", &procType,
-			                &procInfo, &tst)) {
+    while ((poll_rc = bos_ProcessInfoGet(serverHandle, "salvage-tmp", &procType,
+			                &procInfo, &tst))) {
 	sleep(5);
     }
 
