@@ -12,7 +12,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/lwp/process.c,v 1.12.2.1 2002/08/26 04:34:10 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/lwp/process.c,v 1.14 2001/10/26 03:50:06 shadow Exp $");
 
 #include <stdio.h>
 #include <assert.h>
@@ -27,7 +27,7 @@ extern int PRE_Block;              /* used in lwp.c and process.s */
 extern char PRE_Block;             /* used in lwp.c and process.s */
 #endif
 
-#if defined(USE_UCONTEXT) && defined(HAVE_UCONTEXT_H)
+#ifdef HAVE_UCONTEXT_H
 
 afs_int32
 savecontext(ep, savearea, newsp)
@@ -108,6 +108,10 @@ struct lwp_context *savearea;
 #elif defined(AFS_ALPHA_LINUX20_ENV)
 #define LWP_SP 8
 #define LWP_FP 7
+#elif defined(AFS_PARISC_LINUX24_ENV)
+#define LWP_SP 19*2
+	/* really 19 when structure is double, but requires too many changes
+	   below to make a double work */
 #else
 #error Unsupported linux LWP system type.
 #endif
