@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vfsck/setup.c,v 1.3 2001/07/12 19:59:28 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/vfsck/setup.c,v 1.6 2001/09/21 23:48:56 shadow Exp $");
 
 #include <stdio.h>
 #define VICE
@@ -109,7 +109,6 @@ struct bufarea *pbp;
     /* block map */	howmany((fs)->fs_cpg * (fs)->fs_spc / NSPF(fs), NBBY))
 
 char	*malloc(), *calloc();
-char	*index();
 struct	disklabel *getdisklabel();
 
 setup(dev)
@@ -200,7 +199,6 @@ restat:
 	    dev = sname;
 	}
 #endif
-#ifdef	AFS_HPUX_ENV
 	hotroot = is_hotroot(dev);
 
 	/*
@@ -227,9 +225,15 @@ restat:
 	     mounted = swap = 0;
 	     if (!hotroot) {
 		 mounted = is_mounted(dev,&st_mounted);
+#ifdef	AFS_HPUX_ENV
 		 swap = is_swap(st_mounted.st_rdev);
+#endif
 	     }
-	     if (!fflag && !mflag) {
+	     if (!fflag 
+#ifdef  AFS_HPUX_ENV
+&& !mflag
+#endif
+) {
 		 if (hotroot) {
 		     msgprintf("fsck: %s: root file system",dev);
 		     if (preen) 
@@ -257,7 +261,6 @@ restat:
 		 }
 	     }
 	 }
-#endif
 	if (rootdev == statb.st_rdev)
 		hotroot++;
 	if ((fsreadfd = open(dev, O_RDONLY)) < 0) {
@@ -485,8 +488,7 @@ restat:
 	}
 #endif /* AFS_NEWCG_ENV */
 	if (asblk.b_dirty) {
-		bcopy((char *)&sblock, (char *)&altsblock,
-			(int)sblock.fs_sbsize);
+		memcpy((char *)&altsblock, (char *)&sblock, (int)sblock.fs_sbsize);
 		flush(fswritefd, &asblk);
 	}
 	/*
@@ -695,23 +697,18 @@ readsb(listerr)
 #if	!defined(__alpha) && !defined(AFS_SUN56_ENV)
 #if !defined(AFS_HPUX110_ENV)
 	/* HPUX110 will use UpdateAlternateSuper() below */
-	bcopy((char *)sblock.fs_csp, (char *)altsblock.fs_csp,
-		sizeof sblock.fs_csp);
+	memcpy((char *)altsblock.fs_csp, (char *)sblock.fs_csp, sizeof sblock.fs_csp);
 #endif  /* ! AFS_HPUX110_ENV */
 #endif	/* ! __alpha */
 #if	defined(AFS_SUN56_ENV)
-	bcopy((char *)sblock.fs_u.fs_csp_pad, (char *)altsblock.fs_u.fs_csp_pad,
-		sizeof (sblock.fs_u.fs_csp_pad));
+	memcpy((char *)altsblock.fs_u.fs_csp_pad, (char *)sblock.fs_u.fs_csp_pad, sizeof (sblock.fs_u.fs_csp_pad));
 #endif
-	bcopy((char *)sblock.fs_fsmnt, (char *)altsblock.fs_fsmnt,
-		sizeof sblock.fs_fsmnt);
+	memcpy((char *)altsblock.fs_fsmnt, (char *)sblock.fs_fsmnt, sizeof sblock.fs_fsmnt);
 #ifndef	AFS_HPUX_ENV
-	bcopy((char *)sblock.fs_sparecon, (char *)altsblock.fs_sparecon,
-		sizeof sblock.fs_sparecon);
+	memcpy((char *)altsblock.fs_sparecon, (char *)sblock.fs_sparecon, sizeof sblock.fs_sparecon);
 #endif
 #if defined(AFS_DEC_ENV)
-	bcopy((char *)sblock.fs_extra, (char *)altsblock.fs_extra,
-		sizeof sblock.fs_extra);
+	memcpy((char *)altsblock.fs_extra, (char *)sblock.fs_extra, sizeof sblock.fs_extra);
 	altsblock.fs_deftimer = sblock.fs_deftimer;
 	altsblock.fs_lastfsck = sblock.fs_lastfsck;
 	altsblock.fs_gennum = sblock.fs_gennum;
@@ -728,13 +725,12 @@ readsb(listerr)
 #if     defined(AFS_HPUX110_ENV)
 	UpdateAlternateSuper(&sblock, &altsblock);
 #endif  /* AFS_HPUX110_ENV */
-	if (bcmp((char *)&sblock, (char *)&altsblock, (int)sblock.fs_sbsize)) {
+	if (memcmp((char *)&sblock, (char *)&altsblock, (int)sblock.fs_sbsize)) {
 #ifdef	__alpha
-                if (bcmp((char *)&sblock.fs_blank[0],
+                if (memcmp((char *)&sblock.fs_blank[0],
 			 (char *)&altsblock.fs_blank[0],
 			 MAXCSBUFS*sizeof(int))) {
-		    bzero((char *)sblock.fs_blank,
-			  sizeof(sblock.fs_blank));
+		    memset((char *)sblock.fs_blank, 0, sizeof(sblock.fs_blank));
 		} else {
 #endif	/* __alpha */
 		badsb(listerr,
@@ -795,9 +791,10 @@ clean_byte_valid(lastfsck)
 }
 #endif
 
-#ifdef	AFS_HPUX_ENV
 #include <sys/ustat.h>
+#ifdef	AFS_HPUX_ENV
 #include <sys/pstat.h>
+#endif
 #include <sys/errno.h>
 
 extern int errno;
@@ -834,6 +831,8 @@ is_mounted(device,dev_st)
     return (0);
 }
 
+#ifdef	AFS_HPUX_ENV
+
 #define PS_BURST 1
 #ifdef AFS_HPUX102_ENV
 #define PSTAT(P, N, I) pstat_getswap(P, sizeof(*P), (size_t)N, I)
@@ -857,6 +856,9 @@ is_swap(devno)
     return (match);
 }
 
+#endif AFS_HPUX_ENV
+
+
 is_pre_init(rdevnum)
     dev_t rdevnum;
 {
@@ -867,8 +869,17 @@ is_pre_init(rdevnum)
 
 is_roroot()
 {
+#ifndef UID_NO_CHANGE
+    struct stat stslash;
+
+    if (stat("/",&stslash) < 0)
+	return (0);
+    if ( chown("/", stslash.st_uid, stslash.st_gid) == 0 )
+	return(0);
+#else
     if ( chown("/",UID_NO_CHANGE,GID_NO_CHANGE) == 0 )
 	return(0);
+#endif
     else if (errno != EROFS ) {
 	printf ("fsck: chown failed: %d\n",errno);
 	return (0);
@@ -962,7 +973,6 @@ freply(s)
     return (0);
 }
 
-#endif
 
 #if   defined(AFS_HPUX110_ENV)
 /*
