@@ -19,7 +19,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/viced/viced.c,v 1.11.2.3 2002/08/22 01:48:21 zacheiss Exp $");
+RCSID("$Header: /cvs/openafs/src/viced/viced.c,v 1.14 2002/02/22 08:58:21 kolya Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,11 +36,11 @@ RCSID("$Header: /cvs/openafs/src/viced/viced.c,v 1.11.2.3 2002/08/22 01:48:21 za
 #include <sys/file.h>
 #include <netinet/in.h>
 #include <netdb.h>
+#include <sys/resource.h>
 #include <unistd.h>	/* sysconf() */
 #ifndef ITIMER_REAL
 #include <sys/time.h>
 #endif /* ITIMER_REAL */
-#include <sys/resource.h>
 #endif /* AFS_NT40_ENV */
 #include <afs/stds.h>
 #undef SHARED
@@ -1597,7 +1597,7 @@ InitVL() {
 				 AFSDIR_SERVER_NETINFO_FILEPATH,
 				 AFSDIR_SERVER_NETRESTRICT_FILEPATH);
       if (code < 0) {
-	ViceLog(0,("Can' register any valid addresses:%s\n",reason));
+	ViceLog(0,("Can't register any valid addresses: %s\n",reason));
 	exit(1);
       }
       FS_HostAddr_cnt = (afs_uint32) code;
